package models

import (
	"rdluck_tools/orm"
	"time"
)

type CygxArticle struct {
	ArticleId        int       `description:"文章id"`
	Title            string    `description:"标题"`
	TitleEn          string    `description:"英文标题 "`
	UpdateFrequency  string    `description:"更新周期"`
	CreateDate       string    `description:"创建时间"`
	PublishDate      string    `description:"发布时间"`
	Body             string    `description:"内容"`
	Abstract         string    `description:"摘要"`
	CategoryName     string    `description:"一级分类"`
	SubCategoryName  string    `description:"二级分类"`
	InterviewTime    time.Time `description:"访谈时间"`
	ExpertBackground string    `description:"专家背景"`
	ExpertNumber     string    `description:"专家编号"`
}

type HomeArticle struct {
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	ExpertBackground string `description:"专家背景"`
}

type ArticleDetail struct {
	ArticleId            int       `description:"报告id"`
	Title                string    `description:"标题"`
	TitleEn              string    `description:"英文标题 "`
	UpdateFrequency      string    `description:"更新周期"`
	CreateDate           string    `description:"创建时间"`
	PublishDate          string    `description:"发布时间"`
	Body                 string    `description:"内容"`
	Abstract             string    `description:"摘要"`
	CategoryName         string    `description:"一级分类"`
	SubCategoryName      string    `description:"二级分类"`
	IsCollect            bool      `description:"是否收藏:true，已收藏，false:未收藏"`
	IsInterviewApply     bool      `description:"是否申请访谈:true，已申请，false:未申请"`
	BodyText             string    `description:"内容"`
	InterviewApplyStatus string    `description:"当前访谈申请状态：'待邀请','待访谈','已完成','已取消'"`
	InterviewTime        time.Time `description:"访谈时间"`
	ExpertBackground     string    `description:"专家背景"`
	ExpertNumber         string    `description:"专家编号"`
	Department           string    `description:"作者"`
	SellerMobile         string    `description:"销售手机号"`
	SellerName           string    `description:"销售名称"`
	ArticleIdMd5         string    `description:"纪要id"`
}

func GetArticleDetailById(articleId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id = ? `
	err = o.Raw(sql, articleId).QueryRow(&item)
	return
}

func GetArticleDetailByIdMd5(articleIdMd5 string) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id_md5 = ? `
	err = o.Raw(sql, articleIdMd5).QueryRow(&item)
	return
}

func GetArticleDetailByIdStr(articleIdStr string) (items []*ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id IN(` + articleIdStr + `) `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

func GetArticlePermission(categoryName string) (item *ChartPermission, err error) {
	o := orm.NewOrm()
	sql := ` SELECT b.* FROM cygx_permission_mapping AS a
			INNER JOIN chart_permission AS b ON a.chart_permission_id=b.chart_permission_id
			WHERE a.sub_category_name=? `
	err = o.Raw(sql, categoryName).QueryRow(&item)
	return
}

type ArticleDetailResp struct {
	Detail        *ArticleDetail
	HasPermission int `description:"1:有该行业权限,正常展示，2：无该行业权限，不存在权益客户下，3:无该品类权限,已提交过申请，4：无该行业权限,未提交过申请，5：潜在客户，未提交过申请，6：潜在客户,已提交过申请"`
	HasFree       int `description:"1:已付费(至少包含一个品类的权限)，2:未付费(没有任何品类权限)"`
}

func ModifyArticleExpert(articleId int, expertNumStr, expertContentStr, interviewDateStr string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_article SET expert_background=?,expert_number=?,interview_date=? WHERE article_id=? `
	_, err = o.Raw(sql, expertContentStr, expertNumStr, interviewDateStr, articleId).Exec()
	return
}
