package services

import (
	"fmt"
	"hongze/hongze_cygx/models"
	"html"
	"strings"
	"github.com/PuerkitoBio/goquery"
)

func GetReportContentSub(content string) (contentSub string, err error) {
	content = html.UnescapeString(content)
	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	if err != nil {
		fmt.Println("create doc err:", err.Error())
		return
	}
	n := 0
	doc.Find("p").Each(func(i int, s *goquery.Selection) {
		if n > 3 {
			return
		}
		n++
		phtml, err := s.Html()
		if err != nil {
			fmt.Println("get html err", err.Error())
			return
		}
		if s.Text() != "" || strings.Contains(phtml, "src") {
			contentSub = contentSub + "<p>" + phtml + "</p>"
		}
	})
	return
}

func GetReportContentTextSub(content string) (contentSub string, err error) {
	content = html.UnescapeString(content)
	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	if err != nil {
		fmt.Println("create doc err:", err.Error())
		return
	}
	n := 0
	doc.Find("p").Each(func(i int, s *goquery.Selection) {
		if n > 3 {
			return
		}
		n++
		contentSub = contentSub + s.Text()
		//phtml, err := s.Html()
		//if err != nil {
		//	fmt.Println("get html err", err.Error())
		//	return
		//}
		//if s.Text() != "" || !strings.Contains(phtml, "src") {
		//	contentSub = contentSub + "<p>" + phtml + "</p>"
		//}
	})
	return
}

//解析报告
func GetArticleExpert() {
	articleId := 3526
	item, err := models.GetArticleDetailById(articleId)
	if err != nil {
		fmt.Println("GetArticleDetailById Err:" + err.Error())
		return
	}
	content := item.Body
	content = html.UnescapeString(content)
	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	if err != nil {
		fmt.Println("create doc err:", err.Error())
		return
	}

	var expertNumArr []string
	var expertContentArr []string
	var interviewDateArr []string

	doc.Find("p").Each(func(i int, s *goquery.Selection) {
		contentTxt := s.Text()
		if strings.Contains(contentTxt, "#访谈时间：") || strings.Contains(contentTxt, "访谈时间：") {
			interviewDate := s.Next().Text()
			interviewDateArr = append(interviewDateArr, interviewDate)
		}
		if strings.Contains(contentTxt, "#专家评价") || strings.Contains(contentTxt, "专家评价") {
			expertContent := s.Next().Text()
			if expertContent == "" {
				expertContent=contentTxt
			}
			if expertContent != "" {
				rightIndex := strings.Index(expertContent, "）")
				if rightIndex == 0 {
					rightIndex = strings.Index(expertContent, ")")
				}
				expertNum := expertContent[:rightIndex]
				expertNum = strings.Replace(expertNum, "（", "", -1)
				expertNum = strings.Replace(expertNum, "(", "", -1)
				expertNum = strings.Replace(expertNum, "专家评价", "", -1)
				if expertNum != "" {
					expertNumArr = append(expertNumArr, expertNum)
					rightIndex = rightIndex
					expertContentStr := expertContent[rightIndex:]
					expertContentStr = strings.Replace(expertContentStr, "）", "", -1)
					expertContentStr = strings.TrimLeft(expertContentStr, "：")
					expertContentStr = strings.TrimRight(expertContentStr, "（推荐")
					expertContentArr = append(expertContentArr, expertContentStr)
				}
			}
		}
	})
	var expertNumStr, expertContentStr, interviewDateStr string
	if len(expertNumArr) > 0 {
		expertNumStr = expertNumArr[0]
	}
	if len(expertContentArr) > 0 {
		expertContentStr = expertContentArr[0]
	}

	if len(interviewDateArr) > 0 {
		interviewDateStr = interviewDateArr[0]
	}
	fmt.Println(articleId, expertNumStr, expertContentStr, interviewDateStr)
	err = models.ModifyArticleExpert(articleId, expertNumStr, expertContentStr, interviewDateStr)
	if err != nil {
		fmt.Println("ModifyArticleExpert Err:" + err.Error())
		return
	}
}
